@@ -11,19 +11,38 @@ from contextlib import suppress
 from pathlib import Path
 from typing import TYPE_CHECKING
 
-from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS
-from cx_Freeze.hooks._qthooks import get_qt_plugins_paths  # noqa: F401
+from cx_Freeze._compat import IS_CONDA, IS_MACOS, IS_MINGW, IS_WINDOWS
+from cx_Freeze.hooks.qthooks import get_qt_plugins_paths  # noqa: F401
 
 if TYPE_CHECKING:
     from cx_Freeze.finder import ModuleFinder
     from cx_Freeze.module import Module
 
 
+def load_abc(finder: ModuleFinder, module: Module) -> None:
+    """Optimize abc module."""
+    try:
+        finder.include_module("_abc")
+        module.exclude_names.add("_py_abc")
+    except ImportError:
+        finder.include_module("_py_abc")
+        module.ignore_names.add("_abc")
+
+
 def load_aiofiles(finder: ModuleFinder, module: Module) -> None:
     """The aiofiles must be loaded as a package."""
     finder.include_package("aiofiles")
 
 
+def load_argon2(finder: ModuleFinder, module: Module) -> None:
+    """The argon2-cffi package requires the _cffi_backend module
+    (loaded implicitly).
+    """
+    if module.distribution is None:
+        module.update_distribution("argon2-cffi")
+        finder.include_module("_cffi_backend")
+
+
 def load_babel(finder: ModuleFinder, module: Module) -> None:
     """The babel must be loaded as a package, and has pickeable data."""
     finder.include_package("babel")
@@ -34,10 +53,8 @@ def load_bcrypt(finder: ModuleFinder, module: Module) -> None:
     """The bcrypt < 4.0 package requires the _cffi_backend module
     (loaded implicitly).
     """
-    include_cffi = True
-    if module.distribution and module.distribution.version[0] >= 4:
-        include_cffi = False
-    if include_cffi:
+    # bcrypt < 4 supports Python <= 3.10
+    if module.distribution is None or module.distribution.version[0] < 4:
         finder.include_module("_cffi_backend")
 
 
@@ -54,13 +71,6 @@ def load_boto3(finder: ModuleFinder, module: Module) -> None:
     finder.include_files(module.file.parent / "data", "lib/boto3/data")
 
 
-def load_cElementTree(finder: ModuleFinder, module: Module) -> None:
-    """The cElementTree module implicitly loads the elementtree.ElementTree
-    module; make sure this happens.
-    """
-    finder.include_module("elementtree.ElementTree")
-
-
 def load_ceODBC(finder: ModuleFinder, module: Module) -> None:
     """The ceODBC module implicitly imports both datetime and decimal;
     make sure this happens.
@@ -86,11 +96,9 @@ def load__cffi_backend(finder: ModuleFinder, module: Module) -> None:
 def load_cffi_cparser(finder: ModuleFinder, module: Module) -> None:
     """The cffi.cparser module can use a extension if present."""
     try:
-        cffi = __import__("cffi", fromlist=["_pycparser"])
-        pycparser = getattr(cffi, "_pycparser")  # noqa: B009
-        finder.include_module(pycparser.__name__)
-    except (ImportError, AttributeError):
-        finder.exclude_module("cffi._pycparser")
+        finder.include_module("cffi._pycparser")
+    except ImportError:
+        module.ignore_names.add("cffi._pycparser")
 
 
 def load_charset_normalizer(finder: ModuleFinder, module: Module) -> None:
@@ -105,10 +113,9 @@ def load_charset_normalizer_md(finder: ModuleFinder, module: Module) -> None:
         finder.include_module("charset_normalizer.md__mypyc")
 
 
-def load_copy(finder: ModuleFinder, module: Module) -> None:
-    """The copy module should filter import names."""
-    if not sys.platform.startswith("java"):
-        module.exclude_names.add("org.python.core")
+def load_concurrent_futures(finder: ModuleFinder, module: Module) -> None:
+    """Ignore names that should not be confused with modules to be imported."""
+    module.global_names.update(["ProcessPoolExecutor", "ThreadPoolExecutor"])
 
 
 def load_crc32c(finder: ModuleFinder, module: Module) -> None:
@@ -118,39 +125,36 @@ def load_crc32c(finder: ModuleFinder, module: Module) -> None:
 
 def load_cryptography(finder: ModuleFinder, module: Module) -> None:
     """The cryptography module requires the _cffi_backend module."""
+    include_cffi = True
     if module.distribution and module.distribution.requires:
         include_cffi = False
         for req in module.distribution.requires:
             if req.startswith("cffi"):
                 include_cffi = True
                 break
-    else:
-        include_cffi = True
     if include_cffi:
         finder.include_module("_cffi_backend")
 
 
-def load_ctypes(finder: ModuleFinder, module: Module) -> None:
-    """The ctypes module should filter import names."""
-    if not IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.add("nt")
-
-
 def load_ctypes_util(finder: ModuleFinder, module: Module) -> None:
     """The ctypes.util module should filter import names."""
     if not IS_MACOS:
-        module.exclude_names.add("ctypes.macholib.dyld")
+        module.ignore_names.add("ctypes.macholib.dyld")
 
 
 def load__ctypes(finder: ModuleFinder, module: Module) -> None:
-    """In Windows, the _ctypes module in Python 3.8+ requires an additional
-    libffi dll to be present in the build directory.
+    """The _ctypes module requires an additional dependency to be present
+    in the build directory.
     """
     if IS_WINDOWS:
-        dll_pattern = "libffi-*.dll"
-        dll_dir = Path(sys.base_prefix, "DLLs")
-        for dll_path in dll_dir.glob(dll_pattern):
-            finder.include_files(dll_path, Path("lib", dll_path.name))
+        parts = ["DLLs", "Library/bin"]
+        patterns = ["libffi-*.dll", "ffi-*.dll"]
+        for part in parts:
+            for pattern in patterns:
+                for source in Path(sys.base_prefix, part).glob(pattern):
+                    target = f"lib/{source.name}"
+                    finder.lib_files[source] = target
+                    finder.include_files(source, target)
 
 
 def load_cx_Oracle(finder: ModuleFinder, module: Module) -> None:
@@ -162,8 +166,27 @@ def load_cx_Oracle(finder: ModuleFinder, module: Module) -> None:
 
 
 def load_datetime(finder: ModuleFinder, module: Module) -> None:
-    """The datetime module implicitly imports time; make sure this happens."""
-    finder.include_module("time")
+    """Optimize datetime module."""
+    if not hasattr(sys, "stdlib_module_names"):  # py 3.9
+        return
+    if "_pydatetime" in sys.stdlib_module_names:  # py 3.12+
+        try:
+            finder.include_module("_datetime")
+            finder.include_module("time")
+            module.exclude_names.add("_pydatetime")
+        except ImportError:
+            finder.include_module("_pydatetime")
+            module.ignore_names.add("_datetime")
+
+
+def load_decimal(finder: ModuleFinder, module: Module) -> None:
+    """Optimize decimal module."""
+    try:
+        finder.include_module("_decimal")
+        module.exclude_names.add("_pydecimal")
+    except ImportError:
+        finder.include_module("_pydecimal")
+        module.ignore_names.add("_decimal")
 
 
 def load_discord(finder: ModuleFinder, module: Module) -> None:
@@ -183,31 +206,11 @@ def load_docutils_frontend(finder: ModuleFinder, module: Module) -> None:
     module.ignore_names.add("optik")
 
 
-def load_dummy_threading(finder: ModuleFinder, module: Module) -> None:
-    """The dummy_threading module plays games with the name of the threading
-    module for its own purposes; ignore that here.
-    """
-    finder.exclude_module("_dummy_threading")
-
-
-def load_encodings(finder: ModuleFinder, module: Module) -> None:
-    """The encodings module should filter import names."""
-    if not IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.add("_winapi")
-
-
 def load_flask_compress(finder: ModuleFinder, module: Module) -> None:
     """flask-compress requires its metadata."""
     module.update_distribution("Flask_Compress")
 
 
-def load_ftplib(finder: ModuleFinder, module: Module) -> None:
-    """The ftplib module attempts to import the SOCKS module; ignore this
-    module if it cannot be found.
-    """
-    module.ignore_names.add("SOCKS")
-
-
 def load_gevent(finder: ModuleFinder, module: Module) -> None:
     """The gevent must be loaded as a package."""
     finder.include_package("gevent")
@@ -334,18 +337,6 @@ def load_markdown(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("html.parser")
 
 
-def load_mimetypes(finder: ModuleFinder, module: Module) -> None:
-    """The mimetypes module should filter import names."""
-    if not IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.update(("_winapi", "winreg"))
-
-
-def load_ntpath(finder: ModuleFinder, module: Module) -> None:
-    """The ntpath module should filter import names."""
-    if not IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.update(("nt", "_winapi"))
-
-
 def load_Numeric(finder: ModuleFinder, module: Module) -> None:
     """The Numeric module optionally loads the dotblas module; ignore the error
     if this modules does not exist.
@@ -368,25 +359,13 @@ def load_os(finder: ModuleFinder, module: Module) -> None:
     """Sets the alias for os.path."""
     if "posix" in sys.builtin_module_names:
         finder.add_alias("os.path", "posixpath")
-        module.ignore_names.add("nt")
     else:
         finder.add_alias("os.path", "ntpath")
-        module.ignore_names.add("posix")
-
-
-def load_pathlib(finder: ModuleFinder, module: Module) -> None:
-    """The pathlib module should filter import names."""
-    if IS_WINDOWS:
-        module.exclude_names.update(("grp", "pwd"))
-    elif not IS_MINGW:
-        module.exclude_names.add("nt")
 
 
 def load_pickle(finder: ModuleFinder, module: Module) -> None:
     """The pickle module uses doctest for tests and shouldn't be imported."""
     module.exclude_names.add("doctest")
-    if not sys.platform.startswith("java"):
-        module.exclude_names.add("org.python.core")
 
 
 def load_pickletools(finder: ModuleFinder, module: Module) -> None:
@@ -401,15 +380,8 @@ def load_pikepdf(finder: ModuleFinder, module: Module) -> None:
 
 def load_platform(finder: ModuleFinder, module: Module) -> None:
     """The platform module should filter import names."""
-    if not sys.platform.startswith("java"):
-        module.exclude_names.add("java.lang")
-    if not sys.platform.startswith("OpenVMS"):
-        module.exclude_names.add("vms_lib")
     if not IS_MACOS:
         module.exclude_names.add("plistlib")
-    if not IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.add("winreg")
-    module.exclude_names.add("_winreg")
 
 
 def load_plotly(finder: ModuleFinder, module: Module) -> None:
@@ -417,13 +389,6 @@ def load_plotly(finder: ModuleFinder, module: Module) -> None:
     finder.include_package("plotly")
 
 
-def load_posixpath(finder: ModuleFinder, module: Module) -> None:
-    """The posixpath module should filter import names."""
-    if IS_WINDOWS and not IS_MINGW:
-        module.exclude_names.add("posix")
-        module.exclude_names.add("pwd")
-
-
 def load_postgresql_lib(finder: ModuleFinder, module: Module) -> None:
     """The postgresql.lib module requires the libsys.sql file to be included
     so make sure that file is included.
@@ -457,27 +422,6 @@ def load_pycparser(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("pycparser.yacctab")
 
 
-def load_pydantic(finder: ModuleFinder, module: Module) -> None:
-    """The pydantic package is compiled by Cython (the imports are hidden)."""
-    finder.include_module("colorsys")
-    finder.include_module("dataclasses")  # support in v 1.7+
-    finder.include_module("datetime")
-    finder.include_module("decimal")
-    finder.include_module("functools")
-    finder.include_module("ipaddress")
-    finder.include_package("json")
-    finder.include_module("pathlib")
-    finder.include_module("typing_extensions")  # support in v 1.8
-    finder.include_module("uuid")
-
-
-def load_pygments(finder: ModuleFinder, module: Module) -> None:
-    """The pygments package dynamically load styles."""
-    finder.include_package("pygments.styles")
-    finder.include_package("pygments.lexers")
-    finder.include_package("pygments.formatters")
-
-
 def load_pyodbc(finder: ModuleFinder, module: Module) -> None:
     """The pyodbc module implicitly imports others modules;
     make sure this happens.
@@ -516,7 +460,7 @@ def load_pythoncom(finder: ModuleFinder, module: Module) -> None:
     pythoncom = __import__("pythoncom")
     filename = Path(pythoncom.__file__)
     finder.include_files(
-        filename, Path("lib", filename.name), copy_dependent_files=False
+        filename, f"lib/{filename.name}", copy_dependent_files=IS_MINGW
     )
 
 
@@ -530,10 +474,50 @@ def load_pywintypes(finder: ModuleFinder, module: Module) -> None:
     pywintypes = __import__("pywintypes")
     filename = Path(pywintypes.__file__)
     finder.include_files(
-        filename, Path("lib", filename.name), copy_dependent_files=False
+        filename, f"lib/{filename.name}", copy_dependent_files=IS_MINGW
     )
 
 
+def load_re(finder: ModuleFinder, module: Module) -> None:
+    """Ignore names that should not be confused with modules to be imported."""
+    if module.path:  # package since Python 3.11
+        module.global_names.update(
+            [
+                "match",
+                "fullmatch",
+                "search",
+                "sub",
+                "subn",
+                "split",
+                "findall",
+                "finditer",
+                "compile",
+                "purge",
+                "escape",
+                "error",
+                "Pattern",
+                "Match",
+                "A",
+                "I",
+                "L",
+                "M",
+                "S",
+                "X",
+                "U",
+                "ASCII",
+                "IGNORECASE",
+                "LOCALE",
+                "MULTILINE",
+                "DOTALL",
+                "VERBOSE",
+                "UNICODE",
+                "NOFLAG",
+                "RegexFlag",
+                "PatternError",
+            ]
+        )
+
+
 def load_reportlab(finder: ModuleFinder, module: Module) -> None:
     """The reportlab module loads a submodule rl_settings via exec so force
     its inclusion here.
@@ -553,22 +537,6 @@ def load_sentry_sdk(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("sentry_sdk.integrations.threading")
 
 
-def load_shapely(finder: ModuleFinder, module: Module) -> None:
-    """The Shapely.libs directory is not copied."""
-    libs_name = "Shapely.libs"
-    source_dir = module.path[0].parent / libs_name
-    if source_dir.exists():
-        finder.include_files(source_dir, f"lib/{libs_name}")
-
-
-def load_shutil(finder: ModuleFinder, module: Module) -> None:
-    """The shutil module should filter import names."""
-    if IS_WINDOWS:
-        module.exclude_names.update(("grp", "posix", "pwd"))
-    elif not IS_MINGW:
-        module.exclude_names.update(("nt", "_winapi"))
-
-
 def load_site(finder: ModuleFinder, module: Module) -> None:
     """The site module optionally loads the sitecustomize and usercustomize
     modules; ignore the error if these modules do not exist.
@@ -576,36 +544,21 @@ def load_site(finder: ModuleFinder, module: Module) -> None:
     module.ignore_names.update(["sitecustomize", "usercustomize"])
 
 
-def load_six(finder: ModuleFinder, module: Module) -> None:
-    """The six module maps old modules."""
-    module.ignore_names.add("StringIO")
-
-
 def load_sqlite3(finder: ModuleFinder, module: Module) -> None:
     """In Windows, the sqlite3 module requires an additional dll sqlite3.dll to
     be present in the build directory.
     """
     if IS_WINDOWS:
-        dll_name = "sqlite3.dll"
-        dll_path = Path(sys.base_prefix, "DLLs", dll_name)
-        if not dll_path.exists():
-            dll_path = Path(sys.base_prefix, "Library", "bin", dll_name)
-        if dll_path.exists():
-            finder.include_files(dll_path, Path("lib", dll_name))
+        parts = ["DLLs", "Library/bin"]
+        for part in parts:
+            source = Path(sys.base_prefix, part, "sqlite3.dll")
+            if source.exists():
+                target = f"lib/{source.name}"
+                finder.lib_files[source] = target
+                finder.include_files(source, target)
     finder.include_module("sqlite3.dump")
 
 
-def load_subprocess(finder: ModuleFinder, module: Module) -> None:
-    """The subprocess module should filter import names."""
-    if IS_WINDOWS:
-        exclude_names = ("_posixsubprocess", "fcntl", "grp", "pwd")
-    elif not IS_MINGW:
-        exclude_names = ("msvcrt", "_winapi")
-    else:
-        return
-    module.exclude_names.update(exclude_names)
-
-
 def load_sysconfig(finder: ModuleFinder, module: Module) -> None:
     """The sysconfig module implicitly loads _sysconfigdata."""
     if IS_WINDOWS:
@@ -617,12 +570,6 @@ def load_sysconfig(finder: ModuleFinder, module: Module) -> None:
         finder.include_module(get_data_name())
 
 
-def load_tarfile(finder: ModuleFinder, module: Module) -> None:
-    """The tarfile module should filter import names."""
-    if IS_WINDOWS:
-        module.exclude_names.update(("grp", "pwd"))
-
-
 def load_time(finder: ModuleFinder, module: Module) -> None:
     """The time module implicitly loads _strptime; make sure this happens."""
     finder.include_module("_strptime")
@@ -638,6 +585,12 @@ def load_tokenizers(finder: ModuleFinder, module: Module) -> None:
         finder.include_files(source_dir, Path("lib", libs_name))
 
 
+def load_typing(finder: ModuleFinder, module: Module) -> None:
+    """Optimize typing module."""
+    finder.add_alias("typing.io", "io")
+    finder.add_alias("typing.re", "re")
+
+
 def load_twisted_conch_ssh_transport(
     finder: ModuleFinder, module: Module
 ) -> None:
@@ -706,29 +659,24 @@ def load_yaml(finder: ModuleFinder, module: Module) -> None:
     module.update_distribution("PyYAML")
 
 
-def load_zipimport(finder: ModuleFinder, module: Module) -> None:
-    """The module shouldn't import internal names."""
-    module.exclude_names.add("_frozen_importlib")
-    module.exclude_names.add("_frozen_importlib_external")
-
-
-def load_zmq(finder: ModuleFinder, module: Module) -> None:
-    """The zmq package loads zmq.backend.cython dynamically and links
-    dynamically to zmq.libzmq or shared lib. Tested in pyzmq 16.0.4 (py36),
-    19.0.2 (MSYS2 py39) up to 22.2.1 (from pip and from conda).
+def load_zlib(finder: ModuleFinder, module: Module) -> None:
+    """In Windows, the zlib module requires the zlib.dll to be present in the
+    executable directory if using conda-forge. However, the required shared
+    library is zlib1.dll in official Python >= 3.12.
     """
-    finder.include_package("zmq.backend.cython")
-    if IS_WINDOWS or IS_MINGW:
-        # For pyzmq 22 the libzmq dependencies are located in
-        # site-packages/pyzmq.libs
-        libzmq_folder = "pyzmq.libs"
-        libs_dir = module.path[0].parent / libzmq_folder
-        if libs_dir.exists():
-            finder.include_files(libs_dir, Path("lib", libzmq_folder))
-    # Include the bundled libzmq library, if it exists
-    with suppress(ImportError):
-        finder.include_module("zmq.libzmq")
-    finder.exclude_module("zmq.tests")
+    if not IS_WINDOWS:
+        return
+    if IS_CONDA:
+        source = Path(sys.base_prefix, "Library/bin/zlib.dll")
+        if source.exists():
+            target = source.name
+            finder.lib_files[source] = target
+    else:
+        # ensure zlib1.dll is copied if lief is not used in Python 3.12+
+        for source in Path(sys.base_prefix, "DLLs").glob("zlib*.dll"):
+            target = f"lib/{source.name}"
+            finder.lib_files[source] = target
+            finder.include_files(source, target)
 
 
 def load_zope_component(finder: ModuleFinder, module: Module) -> None:
@@ -738,12 +686,9 @@ def load_zope_component(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("pkg_resources")
 
 
-def missing_backports_zoneinfo(finder: ModuleFinder, caller: Module) -> None:
-    """The backports.zoneinfo module should be a drop-in replacement for the
-    Python 3.9 standard library module zoneinfo.
-    """
-    if sys.version_info >= (3, 9):
-        caller.ignore_names.add("backports.zoneinfo")
+#
+# missing section
+#
 
 
 def missing_gdk(finder: ModuleFinder, caller: Module) -> None:
@@ -754,48 +699,12 @@ def missing_gdk(finder: ModuleFinder, caller: Module) -> None:
 
 
 def missing_ltihooks(finder: ModuleFinder, caller: Module) -> None:
-    """The ltihooks module is not necessairly present so ignore it when it
+    """The ltihooks module is not necessarily present so ignore it when it
     cannot be found.
     """
     caller.ignore_names.add("ltihooks")
 
 
-def missing_jnius(finder: ModuleFinder, caller: Module) -> None:
-    """The jnius module is present on java and android."""
-    if not sys.platform.startswith("java"):
-        caller.ignore_names.add("jnius")
-
-
-def missing__manylinux(finder: ModuleFinder, caller: Module) -> None:
-    """The _manylinux module is a flag."""
-    caller.ignore_names.add("_manylinux")
-
-
-def missing_os_path(finder: ModuleFinder, caller: Module) -> None:
-    """The os.path is an alias to posixpath or ntpath."""
-    caller.ignore_names.add("os.path")
-
-
-def missing_readline(finder: ModuleFinder, caller: Module) -> None:
-    """The readline module is not normally present on Windows but it also may
-    be so instead of excluding it completely, ignore it if it can't be found.
-    """
-    if IS_WINDOWS:
-        caller.ignore_names.add("readline")
-
-
 def missing_six_moves(finder: ModuleFinder, caller: Module) -> None:
     """The six module creates fake modules."""
     caller.ignore_names.add("six.moves")
-
-
-def missing_winreg(finder: ModuleFinder, caller: Module) -> None:
-    """The winreg module is present on Windows only."""
-    if not IS_WINDOWS:
-        caller.ignore_names.add("winreg")
-
-
-def missing_zoneinfo(finder: ModuleFinder, caller: Module) -> None:
-    """The zoneinfo module is present in Python 3.9+ standard library."""
-    if sys.version_info < (3, 9):
-        caller.ignore_names.add("zoneinfo")
