@@ -12,12 +12,23 @@ subdirectory that contains the files needed to run the script without Python
 
 from cx_Freeze import setup
 
-options = {"build_exe": {"constants": ["A=7", 'B="hello=7"']}}
-
 setup(
     name="hello",
     version="0.1",
     description="Sample cx_Freeze script",
-    executables=["hello.py"],
-    options=options,
+    executables=[
+        {"script": "hello.py", "copyright": "Copyright (C) 2025 cx_Freeze"}
+    ],
+    options={
+        "build_exe": {
+            "constants": [
+                "USER_UNDEFINED",
+                "USERDEFINED_A=7",
+                'USERDEFINED_B="hello=7"',
+                "USERDEFINED_C=",
+            ],
+            "excludes": ["tkinter", "unittest"],
+            "silent": True,
+        },
+    },
 )
